/*
                      Mixer Channel Device IO

	Sets and gets mixer channel device values.

 */

#ifndef YMIXER_H
#define YMIXER_H

#include "ytypes.h"
#include "ysound.h"
#include "../include/Y2/Ymixercodes.h"


extern int YMixerGet(
        Recorder *recorder,
        int mixer_code,		/* One of YMixerCode*. */
        Coefficient *value
);

extern int YMixerSet(
        Recorder *recorder,
        int mixer_code,		/* One of YMixerCode*. */
	Coefficient *value	/* Each value from 0.0 to 1.0. */
);

#endif	/* YMIXER_H */
